diff pidgin/gtkblist-theme.h @ 23478:4aeef8c3cce3

restructured much of the loader and themes for the buddy list, along with a basic trial of group background color
author Justin Rodriguez <ffdragon@soc.pidgin.im>
date Tue, 15 Jul 2008 06:29:46 +0000
parents a473766abaee
children edb03a8d54bd
line wrap: on
line diff
--- a/pidgin/gtkblist-theme.h	Fri Jul 11 19:13:24 2008 +0000
+++ b/pidgin/gtkblist-theme.h	Tue Jul 15 06:29:46 2008 +0000
@@ -23,38 +23,39 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02111-1301  USA
  */
 
-#ifndef _PIDGIN_BUDDY_LIST_THEME_H_
-#define _PIDGIN_BUDDY_LIST_THEME_H_
+#ifndef _PIDGIN_BLIST_THEME_H_
+#define _PIDGIN_BLIST_THEME_H_
 
 #include <glib.h>
 #include <glib-object.h>
+#include <gtk/gtk.h>
+
 #include "theme.h"
-#include "sound.h"
 
 /**
  * extends PurpleTheme (theme.h)
  * A pidgin buddy list theme.
  * This is an object for Purple to represent a sound theme.
  *
  * PidginBuddyListTheme is a PurpleTheme Object.
  */
-typedef struct _PidginBuddyListTheme        PidginBuddyListTheme;
-typedef struct _PidginBuddyListThemeClass   PidginBuddyListThemeClass;
+typedef struct _PidginBlistTheme        PidginBlistTheme;
+typedef struct _PidginBlistThemeClass   PidginBlistThemeClass;
 
-#define PIDGIN_TYPE_BUDDY_LIST_THEME		  	(pidgin_buddy_list_theme_get_type ())
-#define PIDGIN_BUDDY_LIST_THEME(obj)		  	(G_TYPE_CHECK_INSTANCE_CAST ((obj), PIDGIN_TYPE_BUDDY_LIST_THEME, PidginBuddyListTheme))
-#define PIDGIN_BUDDY_LIST_THEME_CLASS(klass)	  	(G_TYPE_CHECK_CLASS_CAST ((klass), PIDGIN_TYPE_BUDDY_LIST_THEME, PidginBuddyListThemeClass))
-#define PIDGIN_IS_BUDDY_LIST_THEME(obj)	  		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), PIDGIN_TYPE_BUDDY_LIST_THEME))
-#define PIDGIN_IS_BUDDY_LIST_THEME_CLASS(klass) 	(G_TYPE_CHECK_CLASS_TYPE ((klass), PIDGIN_TYPE_BUDDY_LIST_THEME))
-#define PIDGIN_BUDDY_LIST_THEME_GET_CLASS(obj)  	(G_TYPE_INSTANCE_GET_CLASS ((obj), PIDGIN_TYPE_BUDDY_LIST_THEME, PidginBuddyListThemeClass))
+#define PIDGIN_TYPE_BLIST_THEME		  	(pidgin_blist_theme_get_type ())
+#define PIDGIN_BLIST_THEME(obj)		  	(G_TYPE_CHECK_INSTANCE_CAST ((obj), PIDGIN_TYPE_BLIST_THEME, PidginBlistTheme))
+#define PIDGIN_BLIST_THEME_CLASS(klass)	  	(G_TYPE_CHECK_CLASS_CAST ((klass), PIDGIN_TYPE_BLIST_THEME, PidginBlistThemeClass))
+#define PIDGIN_IS_BLIST_THEME(obj)	  	(G_TYPE_CHECK_INSTANCE_TYPE ((obj), PIDGIN_TYPE_BLIST_THEME))
+#define PIDGIN_IS_BLIST_THEME_CLASS(klass) 	(G_TYPE_CHECK_CLASS_TYPE ((klass), PIDGIN_TYPE_BLIST_THEME))
+#define PIDGIN_BLIST_THEME_GET_CLASS(obj)  	(G_TYPE_INSTANCE_GET_CLASS ((obj), PIDGIN_TYPE_BLIST_THEME, PidginBlistThemeClass))
 
-struct _PidginBuddyListTheme
+struct _PidginBlistTheme
 {
 	PurpleTheme parent;
 	gpointer priv;
 };
 
-struct _PidginBuddyListThemeClass
+struct _PidginBlistThemeClass
 {
 	PurpleThemeClass parent_class;
 };
@@ -62,7 +63,7 @@
 typedef struct
 {
 	gchar *font;
-	gchar *color;
+	GdkColor *color;
 
 } font_color_pair;
 
@@ -87,14 +88,14 @@
  * GObject foo.
  * @internal.
  */
-GType pidgin_buddy_list_theme_get_type(void);
+GType pidgin_blist_theme_get_type(void);
 
 /**
  * Returns the icon theme to be used with the buddy list theme
  *
  * @returns 	the icon theme
  */
-const gchar *pidgin_buddy_list_theme_get_icon_theme(PidginBuddyListTheme *theme);
+const gchar *pidgin_blist_theme_get_icon_theme(PidginBlistTheme *theme);
 
 /**
  * Returns the opacity of the buddy list window
@@ -102,91 +103,91 @@
  *
  * @returns 	the opacity
  */
-gdouble pidgin_buddy_list_theme_get_opacity(PidginBuddyListTheme *theme);
+gdouble pidgin_blist_theme_get_opacity(PidginBlistTheme *theme);
 
 /**
  * Returns the layout to be used with the buddy list
  *
  * @returns 	the buddy list layout
  */
-const blist_layout *pidgin_buddy_list_theme_get_layout(PidginBuddyListTheme *theme);
+const blist_layout *pidgin_blist_theme_get_layout(PidginBlistTheme *theme);
 
 /**
  * Returns the background color to be used with expanded groups
  *
  * @returns 	a color
  */
-const gchar *pidgin_buddy_list_theme_get_expanded_background_color(PidginBuddyListTheme *theme);
+const GdkColor *pidgin_blist_theme_get_expanded_background_color(PidginBlistTheme *theme);
 
 /**
  * Returns the text font and color to be used with expanded groups
  *
  * @returns 	a font and color pair
  */
-const font_color_pair *pidgin_buddy_list_theme_get_expanded_text_info(PidginBuddyListTheme *theme);
+const font_color_pair *pidgin_blist_theme_get_expanded_text_info(PidginBlistTheme *theme);
 
 /**
  * Returns the background color to be used with minimized groups
  *
  * @returns 	a color
  */
-const gchar *pidgin_buddy_list_theme_get_minimized_background_color(PidginBuddyListTheme *theme);
+const GdkColor *pidgin_blist_theme_get_collapsed_background_color(PidginBlistTheme *theme);
 
 /**
  * Returns the text font and color to be used with minimized groups
  *
  * @returns 	a font and color pair
  */
-const font_color_pair *pidgin_buddy_list_theme_get_minimized_text_info(PidginBuddyListTheme *theme);
+const font_color_pair *pidgin_blist_theme_get_collapsed_text_info(PidginBlistTheme *theme);
 
 /**
  * Returns the 1st color to be used for buddys
  *
  * @returns 	a color
  */
-const gchar *pidgin_buddy_list_theme_get_buddy_color_1(PidginBuddyListTheme *theme);
+const GdkColor *pidgin_blist_theme_get_buddy_color_1(PidginBlistTheme *theme);
 
 /**
  * Returns the 2nd color to be used for buddies
  *
  * @returns 	a color
  */
-const gchar *pidgin_buddy_list_theme_get_buddy_color_2(PidginBuddyListTheme *theme);
+const GdkColor *pidgin_blist_theme_get_buddy_color_2(PidginBlistTheme *theme);
 
 /**
  * Returns the text font and color to be used for online buddies
  *
  * @returns 	a font and color pair
  */
-const font_color_pair *pidgin_buddy_list_theme_get_online_text_info(PidginBuddyListTheme *theme);
+const font_color_pair *pidgin_blist_theme_get_online_text_info(PidginBlistTheme *theme);
 
 /**
  * Returns the text font and color to be used for away and idle buddies
  *
  * @returns 	a font and color pair
  */
-const font_color_pair *pidgin_buddy_list_theme_get_away_text_info(PidginBuddyListTheme *theme);
+const font_color_pair *pidgin_blist_theme_get_away_text_info(PidginBlistTheme *theme);
 
 /**
  * Returns the text font and color to be used for offline buddies
  *
  * @returns 	a font and color pair
  */
-const font_color_pair *pidgin_buddy_list_theme_get_offline_text_info(PidginBuddyListTheme *theme);
+const font_color_pair *pidgin_blist_theme_get_offline_text_info(PidginBlistTheme *theme);
 
 /**
  * Returns the text font and color to be used for buddies with unread messages
  *
  * @returns 	a font and color pair
  */
-const font_color_pair *pidgin_buddy_list_theme_get_unread_message_text_info(PidginBuddyListTheme *theme);
+const font_color_pair *pidgin_blist_theme_get_unread_message_text_info(PidginBlistTheme *theme);
 
 /**
  * Returns the text font and color to be used for a buddy's status message 
  *
  * @returns 	a font and color pair
  */
-const font_color_pair *pidgin_buddy_list_theme_get_status_text_info(PidginBuddyListTheme *theme);
+const font_color_pair *pidgin_blist_theme_get_status_text_info(PidginBlistTheme *theme);
 
 G_END_DECLS
-#endif /* _PIDGIN_BUDDY_LIST_THEME_H_ */
+#endif /* _PIDGIN_BLIST_THEME_H_ */
@@ -23,38 +23,39 @@
  * This is an object for Purple to represent a sound theme.
  *
- * PidginBuddyListTheme is a PurpleTheme Object.
+ * PidginBlistTheme is a PurpleTheme Object.
  */
@@ -102,91 +103,91 @@
 
 /**
- * Returns the background color to be used with minimized groups
+ * Returns the background color to be used with collapsed groups
  *
  * @returns 	a color
@@ -102,91 +103,91 @@
 
 /**
- * Returns the text font and color to be used with minimized groups
+ * Returns the text font and color to be used with collapsed groups
  *
  * @returns 	a font and color pair